@@ -1,5 +1,7 @@
 package Crypt::NamedKeys;
 
+use strict;
+use warnings;
 use Moo;
 
 =head1 NAME
@@ -25,10 +27,10 @@ data unreadable.
 
 =head1 CONFIGURATION AND KEY ROTATION
 
-The keys are stored in the keyfile, configurable as below.  Keys are numbered 
-starting at 1.  Numbers must never be reused.  Typically key rotation will be 
-done in several steps, each with its own rollout.  These steps MUST be done as 
-separate releases because otherwise keys may not be available to decrypt data, 
+The keys are stored in the keyfile, configurable as below.  Keys are numbered
+starting at 1.  Numbers must never be reused.  Typically key rotation will be
+done in several steps, each with its own rollout.  These steps MUST be done as
+separate releases because otherwise keys may not be available to decrypt data,
 and so things may not work.
 
 =head2 keyfile location
@@ -58,17 +60,17 @@ so for example:
     9: Ceixei4shelohxee1ohdoochuliebael1kae8eit0Geeth1so9fohZi0cohs8go4
     10: boreiDe0shueNgie7shai7ooc1yaeveiKeihuox0xahp1hai8phe7aephiel2oob
 
-In general we assume key spefications to use numeric keys within the named 
-key hash.  This makes key rotation a lot easier and prevents reusing key 
+In general we assume key spefications to use numeric keys within the named
+key hash.  This makes key rotation a lot easier and prevents reusing key
 numbers.
 
 Key names may not contain = or -.
 
 All keys listed can be used for decryption (with the special 'none' key used if
-no key number is specified in the cyphertex), but by default only the default 
+no key number is specified in the cyphertex), but by default only the default
 keynumber (default_keynum, in this case 9) is used for encrypting.
 
-The keynumber is specified in the resulting cyphertext so we know which key 
+The keynumber is specified in the resulting cyphertext so we know which key
 to use for decrypting the cyphertext even if we don't try to decrypt it.  This
 allows:
 
@@ -76,7 +78,7 @@ allows:
 
 =item Key checking
 
-If you store cyphertext in your rdbms, you can check which keys are used before 
+If you store cyphertext in your rdbms, you can check which keys are used before
 you remove decryption support for a key.
 
 =item Orderly key rotation
@@ -117,7 +119,7 @@ This means it is safe then to go onto the second step.
 
 =head2 Step 2:  Setting the new key as default
 
-Once the new keys have been released, the next step is to change the default 
+Once the new keys have been released, the next step is to change the default
 keynumber.  Data encrypted in this way will be available even to servers waiting
 to be updated because the keys have previously been rolled out.  To do this,
 simply change the default_keynum:
@@ -138,12 +140,12 @@ Now all new data will be encrypted using keynumber 2.
 
 =head2 Step 3:  Retiring the old key
 
-Once the old key is no longer being used, it can be retired by deleting the 
+Once the old key is no longer being used, it can be retired by deleting the
 row.
 
 =head2 The Special 'none' keynum
 
-For aes keys before the key versioning was introduced, there is no keynum 
+For aes keys before the key versioning was introduced, there is no keynum
 associated with the cyphertext, so we use this key.
 
 =cut
@@ -157,8 +159,7 @@ use String::Compare::ConstantTime;
 use Try::Tiny;
 use YAML::XS;
 
-
-our $VERSION = '1.1.1';
+our $VERSION = '1.1.2';
 
 =head1 CONFIGURATION PARAMETERS
 
@@ -202,6 +203,7 @@ my $keyfile;
 =head1 METHODS AND FUNCTIONS
 
 =cut
+
 =head2 Crypt::NamedKeys->keyfile($path)
 
 Can also be called as Crypt::NamedKeys::keyfile($path)
@@ -216,19 +218,20 @@ sub keyfile {
     $file = shift if $file eq __PACKAGE__;
     return $keyfile unless $file;
     $keyfile = $file;
+    return $keyfile;
 }
 
 my $keyhash;
 
 my $get_keyhash = sub {
-   return $keyhash if $keyhash;
-   reload_keyhash();
-   return $keyhash;
+    return $keyhash if $keyhash;
+    reload_keyhash();
+    return $keyhash;
 };
 
 =head2 reload_keyhash
 
-Can be called as an object method or function (i.e. 
+Can be called as an object method or function (i.e.
 Crypt::NamedKeys::reload_keyhash()
 
 Loads or reloads the keyfile.  Can be used via event handlers to reload
@@ -254,7 +257,7 @@ sub _default_keynum {
     my $self   = shift;
     my $keytab = &$get_keyhash()->{$self->keyname};
     warn 'No default key found for ' . $self->keyname
-      unless $keytab->{default_keynum};
+        unless $keytab->{default_keynum};
     return $keytab->{default_keynum};
 }
 
@@ -310,12 +313,12 @@ sub encrypt_data {
             keynum  => $self->keynum
         ));
     $data =~ s/=/-/g if $Escape_Eq;
-    $mac =~ s/=/-/g if $Escape_Eq;
+    $mac =~ s/=/-/g  if $Escape_Eq;
     return {
         data => $self->keynum . '*' . $data,
         mac  => $mac,
     };
-} 
+}
 
 =head2 $self->decrypt_data(data => $data, mac => $mac)
 
@@ -367,7 +370,7 @@ sub decrypt_data {
 
 =head2 $self->encrypt_payload(data  => $data)
 
-Encrypts data using I<encrypt_data> and returns result as a string including 
+Encrypts data using I<encrypt_data> and returns result as a string including
 both cyphertext and hmac in base-64 format.  This can work on arbitrary data
 structures, scalars, and references provided that the data can be serialized
 as an attribute on a JSON document.
